.. _tools_module:

:mod:`cubicweb.pyramid.tools`
-----------------------------

.. automodule:: cubicweb.pyramid.tools

    .. autofunction:: includeme

    .. autofunction:: clone_user
    .. autofunction:: cnx_attach_entity
    .. autofunction:: cached_build_user
    .. autofunction:: clear_cache
